# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import enum

import winrt.system
from winrt import _winrt_windows_services_maps_localsearch

__all__ = [
    "LocalLocationFinderStatus",
    "LocalCategories",
    "LocalLocation",
    "LocalLocationFinder",
    "LocalLocationFinderResult",
    "LocalLocationHoursOfOperationItem",
    "LocalLocationRatingInfo",
    "PlaceInfoHelper",
]

class LocalLocationFinderStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    INVALID_CATEGORY = 3
    INVALID_SEARCH_TERM = 4
    INVALID_SEARCH_AREA = 5
    NETWORK_FAILURE = 6
    NOT_SUPPORTED = 7

LocalCategories = _winrt_windows_services_maps_localsearch.LocalCategories
LocalLocation = _winrt_windows_services_maps_localsearch.LocalLocation
LocalLocationFinder = _winrt_windows_services_maps_localsearch.LocalLocationFinder
LocalLocationFinderResult = _winrt_windows_services_maps_localsearch.LocalLocationFinderResult
LocalLocationHoursOfOperationItem = _winrt_windows_services_maps_localsearch.LocalLocationHoursOfOperationItem
LocalLocationRatingInfo = _winrt_windows_services_maps_localsearch.LocalLocationRatingInfo
PlaceInfoHelper = _winrt_windows_services_maps_localsearch.PlaceInfoHelper
